Economic Models to Predict Future Exchange Rates 
================================================ 
 
This section includes planned models for predicting future exchange rates. Contributions are welcome! 
 
- Purchasing Power Parity (PPP) 
- Interest Rate Parity (IRP) 
- Monetary Models of Exchange Rates 
- Portfolio Balance Models 
- Behavioral Equilibrium Exchange Rate (BEER) 
- Fundamental Equilibrium Exchange Rate (FEER) 
